@@ -31,8 +31,8 @@ class MessageHandler(Observable):
 
     def __init__(
         self,
-        memory_service: BaseMemoryService,
-        context_persistent_service: ContextPersistenceService,
+        memory_service: Optional[BaseMemoryService] = None,
+        context_persistent_service: Optional[ContextPersistenceService] = None,
         with_voice: bool = False,
     ):
         """
@@ -67,6 +67,7 @@ class MessageHandler(Observable):
         self.conversation_manager = ConversationManager(self)
 
         self.conversation_manager.start_new_conversation()  # Initialize first conversation
+        self._yolo_mode_check()
 
         # Voice integration
         self.voice_service = None
@@ -87,6 +88,15 @@ class MessageHandler(Observable):
 
                 self.voice_service = DeepInfraVoiceService()
 
+    def _yolo_mode_check(self):
+        # This should allows YOLO can be configured on-the-fly without recalled to config too many times
+        config_management = ConfigManagement()
+        global_config = config_management.read_global_config_data()
+
+        self.tool_manager.yolo_mode = global_config.get("global_settings", {}).get(
+            "yolo_mode", False
+        )
+
     def _messages_append(self, message):
         """Append a message to the agent history and streamline messages."""
         self.streamline_messages.append(message)
@@ -358,13 +368,7 @@ class MessageHandler(Observable):
                     self._messages_append(assistant_message)
                 self._notify("assistant_message_added", assistant_response)
 
-                # This should allows YOLO can be configured on-the-fly without recalled to config too many times
-                config_management = ConfigManagement()
-                global_config = config_management.read_global_config_data()
-
-                self.tool_manager.yolo_mode = global_config.get(
-                    "global_settings", {}
-                ).get("yolo_mode", False)
+                self._yolo_mode_check()
 
                 # Process each tool use
                 for tool_use in tool_uses:
@@ -409,7 +413,7 @@ class MessageHandler(Observable):
                 try:
                     messages_for_this_turn = self.get_recent_agent_responses()
                     if (
-                        messages_for_this_turn
+                        messages_for_this_turn and self.persistent_service
                     ):  # Only save if there are messages for the turn
                         self.persistent_service.append_conversation_messages(
                             self.current_conversation_id,
@@ -469,7 +473,7 @@ class MessageHandler(Observable):
             if self.current_conversation_id and self.last_assisstant_response_idx >= 0:
                 messages_for_this_turn = self.get_recent_agent_responses()
                 if (
-                    messages_for_this_turn
+                    messages_for_this_turn and self.persistent_service
                 ):  # Only save if there are messages for the turn
                     self.persistent_service.append_conversation_messages(
                         self.current_conversation_id,
