@@ -214,6 +214,10 @@ class ChatCompleter(Completer):
             ("/help", "Show help message"),
             ("/retry", "Retry the last assistant response"),
             ("/toggle_transfer", "Toggle agent transfer enforcement on/off"),
+            (
+                "/toggle_session_yolo",
+                "Toggle Auto-Approve Mode for Tool Calls (this session only)",
+            ),
             ("/exit", "Exit the application"),
             ("/quit", "Exit the application"),
         ]
