@@ -9,10 +9,9 @@ import time
 from typing import Any
 from rich.console import Console
 from rich.text import Text
-
-import AgentCrew
 from AgentCrew.modules.chat.message_handler import Observer
 from loguru import logger
+
 from .utils import agent_evaluation_remove
 
 from .constants import (
@@ -339,6 +338,8 @@ class ConsoleUI(Observer):
 
     def print_welcome_message(self):
         """Print the welcome message for the chat."""
+        import AgentCrew
+
         version = getattr(AgentCrew, "__version__", "Unknown")
         self.display_handlers.print_welcome_message(version)
 
@@ -423,6 +424,11 @@ class ConsoleUI(Observer):
                         self.print_welcome_message()
                         continue
 
+                    # Handle toggle_session_yolo command directly (console only, session-based)
+                    elif user_input.strip() == "/toggle_session_yolo":
+                        self.command_handlers.handle_toggle_session_yolo_command()
+                        continue
+
                     elif user_input.strip().startswith("/export_agent "):
                         # Extract arguments after "/export_agent "
                         args = user_input.strip()[14:].strip()
@@ -496,7 +502,7 @@ class ConsoleUI(Observer):
                         or user_input.startswith("/consolidate ")
                         or user_input.startswith("/agent ")
                         or user_input.startswith("/model ")
-                        or user_input.startswith("/retry ")
+                        or user_input.startswith("/retry")
                     ):
                         self.start_loading_animation()
 
