@@ -67,8 +67,14 @@ class InputHandler:
         @kb.add("escape", "enter")
         def _(event):
             """Submit on Ctrl+S."""
-            if event.current_buffer.text.strip() and not self.is_message_processing:
-                event.current_buffer.validate_and_handle()
+            if event.current_buffer.text.strip():
+                # Allow exit commands to be submitted anytime
+                if (
+                    event.current_buffer.text == "/exit"
+                    or event.current_buffer.text == "/quit"
+                    or not self.is_message_processing
+                ):
+                    event.current_buffer.validate_and_handle()
 
         @kb.add(Keys.Enter)
         def _(event):
@@ -151,6 +157,7 @@ class InputHandler:
                     self.display_handlers.print_prompt_prefix(
                         self.message_handler.agent.name,
                         self.message_handler.agent.get_model(),
+                        self.message_handler.tool_manager.get_effective_yolo_mode(),
                     )
                     prompt = Text("👤 YOU: ", style=RICH_STYLE_BLUE)
                     self.console.print(prompt, end="")
@@ -182,7 +189,10 @@ class InputHandler:
         @kb.add(Keys.Backspace)
         def _(event):
             if not event.current_buffer.text:
-                prompt = Text("👤 YOU: ", style=RICH_STYLE_BLUE)
+                prompt = Text(
+                    "👤 YOU: " if not self.is_message_processing else "",
+                    style=RICH_STYLE_BLUE,
+                )
                 self.console.print("", end="\r")
                 self.console.print(prompt, end="")
             else:
@@ -338,12 +348,16 @@ class InputHandler:
         # Start input thread if not already running
         if self._input_thread is None or not self._input_thread.is_alive():
             self.display_handlers.print_prompt_prefix(
-                self.message_handler.agent.name, self.message_handler.agent.get_model()
+                self.message_handler.agent.name,
+                self.message_handler.agent.get_model(),
+                self.message_handler.tool_manager.get_effective_yolo_mode(),
             )
             self._start_input_thread()
         else:
             self.display_handlers.print_prompt_prefix(
-                self.message_handler.agent.name, self.message_handler.agent.get_model()
+                self.message_handler.agent.name,
+                self.message_handler.agent.get_model(),
+                self.message_handler.tool_manager.get_effective_yolo_mode(),
             )
             self.clear_buffer()
 
