@@ -99,6 +99,15 @@ class CustomLLMService(OpenAIService):
                                     tool_content.get("text", "")
                                 )
                     msg["content"] = "\n".join(cleaned_tool_content)
+            elif msg.get("role") == "assistant":
+                if isinstance(msg.get("content", ""), List):
+                    for assistant_content in msg["content"]:
+                        if isinstance(assistant_content, dict):
+                            if assistant_content.get("type", "text") == "thinking":
+                                assistant_content["type"] = "text"
+                                assistant_content["text"] = (
+                                    f"<think>{assistant_content.get('text', '')}</think>"
+                                )
 
         return messages
 
@@ -120,21 +129,21 @@ class CustomLLMService(OpenAIService):
                 [{"role": "system", "content": self.system_prompt}] + messages
             )
 
+        full_model_id = f"{self._provider_name}/{self.model}"
+
         # Add tools if available
         if self.tools and "tool_use" in ModelRegistry.get_model_capabilities(
-            f"{self._provider_name}/{self.model}"
+            full_model_id
         ):
             stream_params["tools"] = self.tools
 
         if (
-            "thinking" in ModelRegistry.get_model_capabilities(self.model)
-            and self.reasoning_effort is None
+            "thinking" in ModelRegistry.get_model_capabilities(full_model_id)
+            and self.reasoning_effort
         ):
-            stream_params["reasoning_effort"] = "none"
+            stream_params["reasoning_effort"] = self.reasoning_effort
 
-        if "stream" in ModelRegistry.get_model_capabilities(
-            f"{self._provider_name}/{self.model}"
-        ):
+        if "stream" in ModelRegistry.get_model_capabilities(full_model_id):
             self._is_thinking = False
             return await self.client.chat.completions.create(
                 **stream_params,
