@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import os
 import json
 import mimetypes
@@ -6,7 +8,7 @@ import itertools
 import rich
 import re
 from rich.live import Live
-from typing import Dict, Any, List, Optional, Tuple
+from typing import TYPE_CHECKING
 from groq import AsyncGroq
 from dotenv import load_dotenv
 from AgentCrew.modules.llm.base import (
@@ -18,6 +20,9 @@ from AgentCrew.modules.llm.base import (
 from AgentCrew.modules.llm.model_registry import ModelRegistry
 from loguru import logger
 
+if TYPE_CHECKING:
+    from typing import Dict, Any, List, Optional, Tuple
+
 
 class GroqService(BaseLLMService):
     """Groq-specific implementation of the LLM service."""
@@ -216,6 +221,7 @@ class GroqService(BaseLLMService):
             "temperature": 0.4,
             "top_p": 0.95,
         }
+        full_model_id = f"{self._provider_name}/{self.model}"
 
         # Add system message if provided
         if self.system_prompt:
@@ -231,9 +237,7 @@ class GroqService(BaseLLMService):
                 + messages
             )
 
-        if "thinking" in ModelRegistry.get_model_capabilities(
-            f"{self._provider_name}/{self.model}"
-        ):
+        if "thinking" in ModelRegistry.get_model_capabilities(full_model_id):
             stream_params["reasoning_format"] = "parsed"
             # stream_params["messages"].append(
             #     {"role": "assistant", "content": "<think>\n"}
@@ -241,7 +245,7 @@ class GroqService(BaseLLMService):
 
         # Add tools if available
         if self.tools and "tool_use" in ModelRegistry.get_model_capabilities(
-            f"{self._provider_name}/{self.model}"
+            full_model_id
         ):
             stream_params["tools"] = self.tools
 
