@@ -352,26 +352,6 @@ _GITHUB_COPILOT_MODELS = [
         input_token_price_1m=0.0,
         output_token_price_1m=0.0,
     ),
-    Model(
-        id="gemini-2.0-flash-001",
-        provider="github_copilot",
-        name="Gemini 2.0 Flash",
-        description="",
-        capabilities=["tool_use", "vision", "stream"],
-        default=False,
-        input_token_price_1m=0.0,
-        output_token_price_1m=0.0,
-    ),
-    Model(
-        id="claude-3.7-sonnet-thought",
-        provider="github_copilot",
-        name="Claude 3.7 Sonnet Thinking",
-        description="",
-        capabilities=["tool_use", "thinking", "vision", "stream"],
-        default=False,
-        input_token_price_1m=0.0,
-        output_token_price_1m=0.0,
-    ),
     Model(
         id="gpt-4.1",
         provider="github_copilot",
@@ -433,16 +413,6 @@ _GITHUB_COPILOT_MODELS = [
         input_token_price_1m=0.0,
         output_token_price_1m=0.0,
     ),
-    Model(
-        id="o4-mini",
-        provider="github_copilot",
-        name="o4 mini",
-        description="",
-        capabilities=["tool_use", "thinking", "stream"],
-        default=False,
-        input_token_price_1m=0.0,
-        output_token_price_1m=0.0,
-    ),
     Model(
         id="o1",
         provider="github_copilot",
@@ -473,16 +443,6 @@ _GITHUB_COPILOT_MODELS = [
         input_token_price_1m=0.0,
         output_token_price_1m=0.0,
     ),
-    Model(
-        id="claude-opus-4",
-        provider="github_copilot",
-        name="Claude Opus 4",
-        description="",
-        capabilities=["tool_use", "vision", "stream", "thinking"],
-        default=False,
-        input_token_price_1m=0.0,
-        output_token_price_1m=0.0,
-    ),
     Model(
         id="claude-opus-4.1",
         provider="github_copilot",
@@ -493,16 +453,6 @@ _GITHUB_COPILOT_MODELS = [
         input_token_price_1m=0.0,
         output_token_price_1m=0.0,
     ),
-    Model(
-        id="o3",
-        provider="github_copilot",
-        name="o3",
-        description="",
-        capabilities=["tool_use", "vision", "stream", "thinking"],
-        default=False,
-        input_token_price_1m=0.0,
-        output_token_price_1m=0.0,
-    ),
 ]
 AVAILABLE_MODELS = (
     _ANTHROPIC_MODELS
